from matplotlib import pyplot as plt
from datetime import datetime, timedelta
from timetable import parse_ical, generate_timetable, clip_timetable
# >>>
icaldata = b"""
BEGIN:VCALENDAR
BEGIN:VEVENT
UID:0
DTSTART:20150101T120000Z
DTEND:20150101T124500Z
RRULE:FREQ=WEEKLY;BYDAY=MO,TU;INTERVAL=2
SUMMARY:spam
END:VEVENT
BEGIN:VEVENT
UID:1
DTSTART:20150101T120000Z
DTEND:20150101T121500Z
RRULE:FREQ=WEEKLY;BYDAY=WE,TH,FR
SUMMARY:eggs
END:VEVENT
END:VCALENDAR
"""
calendar = parse_ical(icaldata)[0]
# >>>
start = datetime(2015, 1, 1)
end = datetime(2015, 3, 1)
timetable = clip_timetable(generate_timetable(calendar), start, end)
# >>>
dates = {b'spam': [start], b'eggs': [start]}
cumulative = {b'spam': [0], b'eggs': [0]}
for start, end, entry in timetable:
    summary = entry['item'][b'summary'][0].value
    time = (end - start).total_seconds() / 3600
    dates[summary].append(end)
    cumulative[summary].append(cumulative[summary][-1] + time)
# >>>
plt.plot(dates[b'spam'], cumulative[b'spam'], color='green', label='spam')
# [...]
plt.plot(dates[b'eggs'], cumulative[b'eggs'], color='orange', label='eggs')
# [...]
plt.legend(loc='upper left')
# <...>
plt.gcf().autofmt_xdate()
plt.show() # doctest: +SKIP
